@@ -71,7 +71,7 @@ const ElementData table_data[] =
 {	N_("Cobalt"),	Q_NA,	"Co",	27,	Series::TRANSITION_METAL,	9,	4,	Block::D,	8.90,	7.75,	Q_NA,	N_("Hard, ductile, lustrous bluish-gray metal"),	Event (1737, N_("Sweden")),	"George Brandt",	N_("German: kobold (evil spirit)"),	58.933195,	6.7,	135,	126,	Q_UNK,	"63 (+3e), 72 (+2e)",	LatticeType::HEX,	194,	FL (3, 250.71, 250.71, 406.95),	FL (3, 90.0, 90.0, 120.0),	"[Ar] 3d<sup>7</sup> 4s<sup>2</sup>",	IL (4, 3, 2, 0, -1),	1.88,	64.0,	760.4,	1768,	3200,	16.06,	377,	0.421,	100,	385,	color (0.44, 0.48, 0.78),	Q_NA,	},
 {	N_("Nickel"),	Q_NA,	"Ni",	28,	Series::TRANSITION_METAL,	10,	4,	Block::D,	8.908,	7.81,	Q_NA,	N_("Hard, malleable, silvery-white metal"),	Event (1751, N_("Sweden")),	"Axel Fredrik Cronstedt",	N_("German: kupfernickel (false copper)"),	58.6934,	6.6,	135,	121,	Q_UNK,	"69 (+2e)",	LatticeType::FCC,	225,	FL (3, 352.4, 352.4, 352.4),	FL (3, 90.0, 90.0, 90.0),	"[Ar] 3d<sup>8</sup> 4s<sup>2</sup>",	IL (3, 3, 2, 0),	1.91,	111.6,	737.1,	1728,	3186,	17.48,	377.5,	0.444,	90.9,	375,	color (0.36, 0.48, 0.76),	Q_NA,	},
 {	N_("Copper"),	"Cuprum",	"Cu",	29,	Series::TRANSITION_METAL,	11,	4,	Block::D,	8.96,	8.02,	Q_NA,	N_("Malleable, ductile, reddish-brown metal"),	Q_NA,	Q_UNK,	N_("Late Latin: cuprum, Latin: [aes] Cyprium (metal of Cyprus)"),	63.546,	7.1,	135,	138,	Q_UNK,	"72 (+2e), 96 (+1e)",	LatticeType::FCC,	225,	FL (3, 361.49, 361.49, 361.49),	FL (3, 90.0, 90.0, 90.0),	"[Ar] 3d<sup>10</sup> 4s<sup>1</sup>",	IL (2, 2, 1),	1.90,	119.24,	745.5,	1357.77,	2835,	13.26,	300.4,	0.385,	401,	315,	color (1.00, 0.48, 0.38),	Q_NA,	},
-{	N_("Zinc"),	Q_NA,	"Zn",	30,	Series::TRANSITION_METAL,	12,	4,	Block::D,	7.14,	6.57,	Q_NA,	N_("Bluish-silver, ductile metal"),	Event (1526, N_("Switzerland")),	"Paracelsus",	N_("German: zink (tin)"),	65.409,	9.2,	135,	131,	210,	"74 (+2e)",	LatticeType::HEX,	194,	FL (3, 266.49, 266.49, 494.68),	FL (3, 90.0, 90.0, 120.0),	"[Ar] 3d<sup>10</sup> 4s<sup>2</sup>",	IL (1, 2),	1.65,	F (0, Q_EST),	906.4,	692.68,	1180,	7.32,	123.6,	0.388,	116,	234,	color (0.49, 0.50, 0.69),	Q_NA,	},
+{	N_("Zinc"),	Q_NA,	"Zn",	30,	Series::TRANSITION_METAL,	12,	4,	Block::D,	7.14,	6.57,	Q_NA,	N_("Bluish-silver, ductile metal"),	Event (1526, N_("Switzerland")),	"Paracelsus",	N_("German: zink (sharp point, prong, tooth)"),	65.409,	9.2,	135,	131,	210,	"74 (+2e)",	LatticeType::HEX,	194,	FL (3, 266.49, 266.49, 494.68),	FL (3, 90.0, 90.0, 120.0),	"[Ar] 3d<sup>10</sup> 4s<sup>2</sup>",	IL (1, 2),	1.65,	F (0, Q_EST),	906.4,	692.68,	1180,	7.32,	123.6,	0.388,	116,	234,	color (0.49, 0.50, 0.69),	Q_NA,	},
 {	N_("Gallium"),	Q_NA,	"Ga",	31,	Series::POST_TRANSITION_METAL,	13,	4,	Block::P,	5.91,	6.095,	Q_NA,	N_("Soft, blue-white metal"),	Event (1875, N_("France")),	N_("Paul &#201;mile Lecoq de Boisbaudran"),	N_("Latin: Gallia (Gaul, an ancient area including modern France)"),	69.723,	11.8,	130,	126,	210,	"62 (+3e), 81 (+1e)",	LatticeType::ORTH,	64,	FL (3, 451.97, 766.33, 452.6),	FL (3, 90.0, 90.0, 90.0),	"[Ar] 3d<sup>10</sup> 4s<sup>2</sup> 4p<sup>1</sup>",	IL (1, 3),	1.81,	41,	578.8,	302.9146,	2477,	5.59,	254,	0.371,	40.6,	240,	color (0.76, 0.56, 0.56),	Q_NA,	},
 {	N_("Germanium"),	Q_NA,	"Ge",	32,	Series::SEMIMETAL,	14,	4,	Block::P,	5.323,	5.60,	Q_NA,	N_("Grayish-white metal"),	Event (1886, N_("Germany")),	"Clemens Winkler",	N_("Named after Germany (Latin: Germania), where it was discovered."),	72.64,	13.6,	125,	122,	210,	"53 (+4e), 73 (+2e)",	LatticeType::FCC,	225,	FL (3, 565.75, 565.75, 565.75),	FL (3, 90.0, 90.0, 90.0),	"[Ar] 3d<sup>10</sup> 4s<sup>2</sup> 4p<sup>2</sup>",	IL (1, 4),	2.01,	118.94,	762,	1211.40,	3106,	36.94,	334,	0.320,	60.2,	360,	color (0.40, 0.56, 0.56),	Q_NA,	},
 {	N_("Arsenic"),	Q_NA,	"As",	33,	Series::SEMIMETAL,	15,	4,	Block::P,	5.727,	5.22,	Q_NA,	N_("Steel gray, brittle semimetal"),	Event (1250, N_("Germany")),	"Albertus Magnus",	N_("Persian: zarnik (yellow pigment)"),	74.92160,	13.1,	115,	119,	205,	"46 (+5e), 222 (-3e)",	LatticeType::RHO,	166,	FL (3, 375.98, 375.98, 1054.75),	FL (3, 90.0, 90.0, 120.0),	"[Ar] 3d<sup>10</sup> 4s<sup>2</sup> 4p<sup>3</sup>",	IL (3, 5, 3, -2),	2.18,	78.5,	947.0,	1090,	887,	24.44,	Q_NA,	0.329,	50.2,	285,	color (0.74, 0.50, 0.89),	Q_NA,	},
@@ -133,7 +133,7 @@ const ElementData table_data[] =
 {	N_("Astatine"),	Q_NA,	"At",	85,	Series::HALOGEN,	17,	6,	Block::P,	Q_UNK,	Q_UNK,	Q_NA,	N_("Unstable, radioactive halogen"),	Event (1940, N_("United States")),	N_("Dale R. Corson, K.R. MacKenzie, Emilio Segr&#232;"),	N_("Greek: astatos (unstable)"),	F (210, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	"62 (+7e)",	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	"[Xe] 4f<sup>14</sup> 5d<sup>10</sup> 6s<sup>2</sup> 6p<sup>5</sup>",	IL (5, 7, 5, 3, 1, -1),	2.2,	Q_UNK,	F (920, Q_EST),	575,	F (610, Q_EST),	Q_UNK,	F (40, Q_CA),	Q_UNK,	1.7,	Q_UNK,	color (0.46, 0.31, 0.27),	Q_NA,	},
 {	N_("Radon"),	Q_NA,	"Rn",	86,	Series::NOBLE_GAS,	18,	6,	Block::P,	Q_NA,	Q_UNK,	9.73,	N_("Heavy radioactive gas"),	Event (1898, N_("Germany")),	"Friedrich Ernst Dorn",	N_("Named after the element radium, from which it is produced by radioactive decay."),	F (222, Q_ISO),	Q_UNK,	F (120, Q_EST),	145,	Q_UNK,	Q_NA,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	"[Xe] 4f<sup>14</sup> 5d<sup>10</sup> 6s<sup>2</sup> 6p<sup>6</sup>",	Q_NA,	Q_UNK,	F (0, Q_EST),	1037,	202,	211.3,	3.247,	18.10,	0.094,	0.00361,	Q_UNK,	color (0.26, 0.51, 0.59),	Q_NA,	},
 
-{	N_("Francium"),	Q_NA,	"Fr",	87,	Series::ALKALI_METAL,	1,	7,	Block::S,	Q_UNK,	Q_UNK,	Q_NA,	Q_UNK,	Event (1939, N_("France")),	"Marguerite Derey",	N_("Named after France, where it was discovered."),	F (223, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	"180 (+1e)",	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	"[Rn] 7s<sup>1</sup>",	IL (1, 2),	0.7,	Q_UNK,	380,	300,	F (950, Q_EST),	F (2, Q_CA),	F (65, Q_CA),	F (0.143, Q_ISO),	Q_UNK,	Q_UNK,	color (0.26, 0.00, 0.40),	Q_NA,	},
+{	N_("Francium"),	Q_NA,	"Fr",	87,	Series::ALKALI_METAL,	1,	7,	Block::S,	Q_UNK,	Q_UNK,	Q_NA,	Q_UNK,	Event (1939, N_("France")),	"Marguerite Perey",	N_("Named after France, where it was discovered."),	F (223, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	"180 (+1e)",	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	"[Rn] 7s<sup>1</sup>",	IL (1, 2),	0.7,	Q_UNK,	380,	300,	F (950, Q_EST),	F (2, Q_CA),	F (65, Q_CA),	F (0.143, Q_ISO),	Q_UNK,	Q_UNK,	color (0.26, 0.00, 0.40),	Q_NA,	},
 {	N_("Radium"),	Q_NA,	"Ra",	88,	Series::ALKALINE_EARTH_METAL,	2,	7,	Block::S,	5.5,	Q_UNK,	Q_NA,	N_("Silvery white, radioactive element"),	Event (1898, N_("France")),	N_("Marie Curie-Sk&#322;odowska, Pierre Curie"),	N_("Latin: radius (ray)"),	F (226, Q_ISO),	45.0,	215,	Q_UNK,	Q_UNK,	"143 (+2e)",	LatticeType::BCC,	229,	FL (3, 514.8, 514.8, 514.8),	FL (3, 90.0, 90.0, 90.0),	"[Rn] 7s<sup>2</sup>",	IL (1, 2),	0.9,	Q_UNK,	509.3,	973,	2010,	8.5,	113,	Q_UNK,	18.6,	Q_UNK,	color (0.00, 0.49, 0.00),	Q_NA,	},
 
 {	N_("Actinium"),	Q_NA,	"Ac",	89,	Series::ACTINIDE,	3,	7,	Block::F,	F (10, Q_ISO),	Q_UNK,	Q_NA,	N_("Heavy, silvery-white metal that is very radioactive"),	Event (1899, N_("France")),	N_("Andr&#233;-Louis Debierne"),	N_("Greek: aktis, aktinos (ray)"),	F (227, Q_ISO),	22.54,	195,	Q_UNK,	Q_UNK,	"118 (+3e)",	LatticeType::FCC,	225,	FL (3, 567.0, 567.0, 567.0),	FL (3, 90.0, 90.0, 90.0),	"[Rn] 6d<sup>1</sup> 7s<sup>2</sup>",	IL (1, 3),	1.1,	Q_UNK,	499,	F (1323, Q_CA),	F (3471, Q_ISO),	14,	400,	0.120,	12,	Q_UNK,	color (0.44, 0.67, 0.98),	Q_NA,	},
@@ -160,13 +160,13 @@ const ElementData table_data[] =
 {	N_("Meitnerium"),	Q_NA,	"Mt",	109,	Series::TRANSITION_METAL,	9,	7,	Block::D,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (1982, N_("Germany")),	N_("Peter Armbruster, Gottfried M&#252;nzenberg, et al. (Inst. for Heavy Ion Research)"),	N_("Named in honor of Austrian-Swedish physicist Lise Meitner."),	F (268, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.92, 0.00, 0.15),	Q_NA,	},
 {	N_("Darmstadtium"),	Q_NA,	"Ds",	110,	Series::TRANSITION_METAL,	10,	7,	Block::D,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (1994, N_("Germany")),	N_("S. Hofmann, V. Ninov, et al. (Inst. for Heavy Ion Research)"),	N_("Named after Darmstadt, Germany, where it was discovered."),	F (281, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.93, 0.00, 0.14),	Q_NA,	},
 {	N_("Roentgenium"),	Q_NA,	"Rg",	111,	Series::TRANSITION_METAL,	11,	7,	Block::D,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (1994, N_("Germany")),	N_("S. Hofmann, V. Ninov, et al. (Inst. for Heavy Ion Research)"),	N_("Named in honor of German physicist Wilhelm Roentgen, who discovered x-rays."),	F (272, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.94, 0.00, 0.13),	Q_NA,	},
-{	N_("Ununbium"),	Q_NA,	"Uub",	112,	Series::TRANSITION_METAL,	12,	7,	Block::D,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (1996, N_("Germany")),	N_("Inst. for Heavy Ion Research"),	N_("IUPAC systematic name"),	F (285, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.95, 0.00, 0.12),	Q_NA,	},
-{	N_("Ununtrium"),	Q_NA,	"Uut",	113,	Series::POST_TRANSITION_METAL,	13,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (2004, N_("Russia/United States")),	N_("Joint Inst. for Nuclear Research / Lawrence Livermore Lab."),	N_("IUPAC systematic name"),	F (284, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.96, 0.00, 0.11),	Q_NA,	},
-{	N_("Ununquadium"),	Q_NA,	"Uuq",	114,	Series::POST_TRANSITION_METAL,	14,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (1999, N_("Russia")),	N_("Joint Inst. for Nuclear Research"),	N_("IUPAC systematic name"),	F (289, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.97, 0.00, 0.10),	Q_NA,	},
-{	N_("Ununpentium"),	Q_NA,	"Uup",	115,	Series::POST_TRANSITION_METAL,	15,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (2004, N_("Russia/United States")),	N_("Joint Inst. for Nuclear Research / Lawrence Livermore Lab."),	N_("IUPAC systematic name"),	F (288, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.98, 0.00, 0.09),	Q_NA,	},
-{	N_("Ununhexium"),	Q_NA,	"Uuh",	116,	Series::POST_TRANSITION_METAL,	16,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (2001, N_("Russia")),	N_("Joint Inst. for Nuclear Research"),	N_("IUPAC systematic name"),	F (292, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.99, 0.00, 0.08),	Q_NA,	},
-{	N_("Ununseptium"),	Q_NA,	"Uus",	117,	Q_UNK,	17,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_NA,	N_("IUPAC systematic name"),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_NA,	Q_NA,	},
-{	N_("Ununoctium"),	Q_NA,	"Uuo",	118,	Series::NOBLE_GAS,	18,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (2006, N_("Russia/United States")),	N_("Joint Inst. for Nuclear Research / Lawrence Livermore Lab."),	N_("IUPAC systematic name"),	F (294, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_NA,	Q_NA,	},
+{	N_("Copernicium"),	Q_NA,	"Cn",	112,	Series::TRANSITION_METAL,	12,	7,	Block::D,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (1996, N_("Germany")),	N_("Inst. for Heavy Ion Research"),	N_("Named in honor of the astronomer Nicolaus Copernicus."),	F (285, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.95, 0.00, 0.12),	Q_NA,	},
+{	N_("Nihonium"),		Q_NA,	"Nh",	113,	Series::POST_TRANSITION_METAL,	13,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (2004, N_("Japan")),	N_("RIKEN Nishina Center for Accelerator-Based Science, Japan"),	N_("Japanese: Nihon (the Land of Rising Sun)"),	F (284, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.96, 0.00, 0.11),	Q_NA,	},
+{	N_("Flerovium"),	Q_NA,	"Fl",	114,	Series::POST_TRANSITION_METAL,	14,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (1999, N_("Russia")),	N_("Joint Inst. for Nuclear Research"),	N_("Named after the Flerov Laboratory of Nuclear Reactions of the Joint Inst. for Nuclear Research in Dubna, Russia, where it was discovered."),	F (289, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.97, 0.00, 0.10),	Q_NA,	},
+{	N_("Moscovium"),	Q_NA,	"Mc",	115,	Series::POST_TRANSITION_METAL,	15,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (2003, N_("Russia/United States")),	N_("Joint Inst. for Nuclear Research / Lawrence Livermore Lab."),	N_("Named after Moscow, Russia"),	F (288, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.98, 0.00, 0.09),	Q_NA,	},
+{	N_("Livermorium"),	Q_NA,	"Lv",	116,	Series::POST_TRANSITION_METAL,	16,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (2001, N_("Russia")),	N_("Joint Inst. for Nuclear Research"),	N_("The name recognizes the Lawrence Livermore National Laboratory, California, which collaborated with the Joint Inst. for Nuclear Research (JINR), Russia on the discovery."),	F (292, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.99, 0.00, 0.08),	Q_NA,	},
+{	N_("Tennessine"),	Q_NA,	"Ts",	117,	Series::POST_TRANSITION_METAL,	17,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (2009, N_("Russia/United States")),	N_("Joint Inst. for Nuclear Research / Lawrence Livermore National Lab. / Vanderbilt University / Oak Ridge National Lab."),	N_("Named after Tennessee, United States"),	F (294, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (1.00, 0.00, 0.07),	Q_NA,	},
+{	N_("Oganesson"),	Q_NA,	"Og",	118,	Series::NOBLE_GAS,	18,	7,	Block::P,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Event (2002, N_("Russia/United States")),	N_("Joint Inst. for Nuclear Research / Lawrence Livermore National Lab."),	N_("Named after nuclear physicist Yuri Oganessian"),	F (294, Q_ISO),	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	Q_UNK,	color (0.16, 0.40, 0.49),	Q_NA,	},
 
 }; // ElementData table_data[]
 
